@@ -1,6 +1,6 @@
-from rest_framework.permissions import BasePermission
+from rest_framework.permissions import IsAuthenticated
 
 
-class IsCommissionAdmin(BasePermission):
+class IsCommissionAdmin(IsAuthenticated):
     def has_permission(self, request, view):
         return request.user.has_perm("wbcommission.administrate_commission")
